# =============================================================================
# Minet Default Values Collection
# =============================================================================
#
# Listing sane default values used throughout the whole library.
#

# Fetch-related
DEFAULT_GROUP_PARALLELISM = 1
DEFAULT_GROUP_BUFFER_SIZE = 25
DEFAULT_THROTTLE = 0.2
DEFAULT_CONNECT_TIMEOUT = 5
DEFAULT_READ_TIMEOUT = 25
DEFAULT_SPOOFED_UA = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.13; rv:69.0) Gecko/20100101 Firefox/69.0'
